@@ -5,8 +5,8 @@ from flask.json import JSONEncoder
 
 from sqlalchemy.orm.collections import InstrumentedList
 
-from sqlalchemy_abc import serialize
-from sqlalchemy_abc import iserialize
+from sqlalchemy_blender import serialize
+from sqlalchemy_blender import iserialize
 from handyhttp import HTTPException
 
 
