@@ -1,13 +1,13 @@
 from flask import Blueprint
 from flask import request
 
-from sqlalchemy_abc import QueryBuffer
-from sqlalchemy_abc.helpers import related
-from sqlalchemy_abc.helpers import serialize
-from sqlalchemy_abc.helpers import iserialize
-from sqlalchemy_abc.helpers import columns
-from sqlalchemy_abc.helpers import getschema
-from sqlalchemy_abc.dao import ModelDAO
+from sqlalchemy_blender import QueryBuffer
+from sqlalchemy_blender.helpers import related
+from sqlalchemy_blender.helpers import serialize
+from sqlalchemy_blender.helpers import iserialize
+from sqlalchemy_blender.helpers import columns
+from sqlalchemy_blender.helpers import getschema
+from sqlalchemy_blender.dao import ModelDAO
 
 from handyhttp.responses import HTTPSuccess
 from handyhttp.responses import HTTPCreated
@@ -18,6 +18,9 @@ from .cache import link
 from . import cache
 
 
+DEFAULT_METHODS = ['GET', 'POST', 'PUT', 'DELETE', 'HEAD']
+
+
 def bind(blueprint, methods, tenant=None):
     for key in cache.ROUTE_TABLE.keys():
         endpoint = getattr(blueprint, key, None)
@@ -49,7 +52,7 @@ def bind(blueprint, methods, tenant=None):
 
 class RouteBuilder(Blueprint):
 
-    def __init__(self, name, module, model, decorators, dao=None, **kwargs):
+    def __init__(self, name, module, model, decorators=None, dao=None, **kwargs):
         super().__init__(name, module)
         self.decorators = decorators
         self.model = model
@@ -76,6 +79,7 @@ class RouteBuilder(Blueprint):
         if 'key' in kwargs.keys():
             self.key = getattr(self.model, kwargs.get('key'))
         self.delete_flag = False
+        self.bind(getattr(self, 'methods', None) or DEFAULT_METHODS)
 
     def _before_request(self):
         self.querystring()
@@ -167,7 +171,10 @@ class RouteBuilder(Blueprint):
 
     @link(url='/', methods=['POST'])
     def post(self, *args, **kwargs):
-        instance = self.dao.create(self._payload(), **kwargs)
+        try:
+            instance = self.dao.create(self._payload(), **kwargs)
+        except Exception as exc:
+            raise ValueError(str(exc))
         return HTTPCreated(self.json(instance))
 
     @link(url='/<int:modelid>/<resource>/', methods=['POST'])
